==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/importexport/kotlin/inputs/PackageInformationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.importexport.kotlin.inputs

import com.pulumi.azurenative.importexport.inputs.PackageInformationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Double
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Contains information about the package being shipped by the customer to the Microsoft data center.
 * @property carrierName The name of the carrier that is used to ship the import or export drives.
 * @property driveCount The number of drives included in the package.
 * @property shipDate The date when the package is shipped.
 * @property trackingNumber The tracking number of the package.
 */
public data class PackageInformationArgs(
    public val carrierName: Output<String>,
    public val driveCount: Output<Double>,
    public val shipDate: Output<String>,
    public val trackingNumber: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.importexport.inputs.PackageInformationArgs> {
    override fun toJava(): com.pulumi.azurenative.importexport.inputs.PackageInformationArgs =
        com.pulumi.azurenative.importexport.inputs.PackageInformationArgs.builder()
            .carrierName(carrierName.applyValue({ args0 -> args0 }))
            .driveCount(driveCount.applyValue({ args0 -> args0 }))
            .shipDate(shipDate.applyValue({ args0 -> args0 }))
            .trackingNumber(trackingNumber.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PackageInformationArgs].
 */
@PulumiTagMarker
public class PackageInformationArgsBuilder internal constructor() {
    private var carrierName: Output<String>? = null

    private var driveCount: Output<Double>? = null

    private var shipDate: Output<String>? = null

    private var trackingNumber: Output<String>? = null

    /**
     * @param value The name of the carrier that is used to ship the import or export drives.
     */
    @JvmName("nfpqvfuwkvbwbaqb")
    public suspend fun carrierName(`value`: Output<String>) {
        this.carrierName = value
    }

    /**
     * @param value The number of drives included in the package.
     */
    @JvmName("bipvucbrkiqqcvrb")
    public suspend fun driveCount(`value`: Output<Double>) {
        this.driveCount = value
    }

    /**
     * @param value The date when the package is shipped.
     */
    @JvmName("ldkrskukmqfdkunp")
    public suspend fun shipDate(`value`: Output<String>) {
        this.shipDate = value
    }

    /**
     * @param value The tracking number of the package.
     */
    @JvmName("tedfxentbvtswldy")
    public suspend fun trackingNumber(`value`: Output<String>) {
        this.trackingNumber = value
    }

    /**
     * @param value The name of the carrier that is used to ship the import or export drives.
     */
    @JvmName("alhcggohdbwvnctl")
    public suspend fun carrierName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.carrierName = mapped
    }

    /**
     * @param value The number of drives included in the package.
     */
    @JvmName("yyfhqmhxodednsvu")
    public suspend fun driveCount(`value`: Double) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.driveCount = mapped
    }

    /**
     * @param value The date when the package is shipped.
     */
    @JvmName("whxmbmqhwkcalhye")
    public suspend fun shipDate(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.shipDate = mapped
    }

    /**
     * @param value The tracking number of the package.
     */
    @JvmName("babvxfvrwfsojysk")
    public suspend fun trackingNumber(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.trackingNumber = mapped
    }

    internal fun build(): PackageInformationArgs = PackageInformationArgs(
        carrierName = carrierName ?: throw PulumiNullFieldException("carrierName"),
        driveCount = driveCount ?: throw PulumiNullFieldException("driveCount"),
        shipDate = shipDate ?: throw PulumiNullFieldException("shipDate"),
        trackingNumber = trackingNumber ?: throw PulumiNullFieldException("trackingNumber"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/importexport/kotlin/inputs/PackageInformationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.importexport.kotlin.inputs

import com.pulumi.azurenative.importexport.inputs.PackageInformationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Double
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Contains information about the package being shipped by the customer to the Microsoft data center.
 * @property carrierName The name of the carrier that is used to ship the import or export drives.
 * @property driveCount The number of drives included in the package.
 * @property shipDate The date when the package is shipped.
 * @property trackingNumber The tracking number of the package.
 */
public data class PackageInformationArgs(
    public val carrierName: Output<String>,
    public val driveCount: Output<Double>,
    public val shipDate: Output<String>,
    public val trackingNumber: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.importexport.inputs.PackageInformationArgs> {
    override fun toJava(): com.pulumi.azurenative.importexport.inputs.PackageInformationArgs =
        com.pulumi.azurenative.importexport.inputs.PackageInformationArgs.builder()
            .carrierName(carrierName.applyValue({ args0 -> args0 }))
            .driveCount(driveCount.applyValue({ args0 -> args0 }))
            .shipDate(shipDate.applyValue({ args0 -> args0 }))
            .trackingNumber(trackingNumber.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PackageInformationArgs].
 */
@PulumiTagMarker
public class PackageInformationArgsBuilder internal constructor() {
    private var carrierName: Output<String>? = null

    private var driveCount: Output<Double>? = null

    private var shipDate: Output<String>? = null

    private var trackingNumber: Output<String>? = null

    /**
     * @param value The name of the carrier that is used to ship the import or export drives.
     */
    @JvmName("xqvfxedlmovvokte")
    public suspend fun carrierName(`value`: Output<String>) {
        this.carrierName = value
    }

    /**
     * @param value The number of drives included in the package.
     */
    @JvmName("fuugmimkpmsyuwun")
    public suspend fun driveCount(`value`: Output<Double>) {
        this.driveCount = value
    }

    /**
     * @param value The date when the package is shipped.
     */
    @JvmName("kiyugbirckujnqpv")
    public suspend fun shipDate(`value`: Output<String>) {
        this.shipDate = value
    }

    /**
     * @param value The tracking number of the package.
     */
    @JvmName("rdckbgrhfeplukgy")
    public suspend fun trackingNumber(`value`: Output<String>) {
        this.trackingNumber = value
    }

    /**
     * @param value The name of the carrier that is used to ship the import or export drives.
     */
    @JvmName("mhdtypbenqegnaov")
    public suspend fun carrierName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.carrierName = mapped
    }

    /**
     * @param value The number of drives included in the package.
     */
    @JvmName("xeppvypaejcnbcav")
    public suspend fun driveCount(`value`: Double) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.driveCount = mapped
    }

    /**
     * @param value The date when the package is shipped.
     */
    @JvmName("pqjtaclxosirqglm")
    public suspend fun shipDate(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.shipDate = mapped
    }

    /**
     * @param value The tracking number of the package.
     */
    @JvmName("omqhrtyywhggqvqg")
    public suspend fun trackingNumber(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.trackingNumber = mapped
    }

    internal fun build(): PackageInformationArgs = PackageInformationArgs(
        carrierName = carrierName ?: throw PulumiNullFieldException("carrierName"),
        driveCount = driveCount ?: throw PulumiNullFieldException("driveCount"),
        shipDate = shipDate ?: throw PulumiNullFieldException("shipDate"),
        trackingNumber = trackingNumber ?: throw PulumiNullFieldException("trackingNumber"),
    )
}
